"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertQueryToPropertyFilters = exports.createPropertyFilter = exports.reportLog = void 0;
var fs = require("fs");
var reportLog = function (logger, inputFile, outputFile, keys, count) {
    var inputFileSizeInBytes = fs.statSync(inputFile).size;
    var outputFileSizeInBytes = fs.statSync(outputFile).size;
    var percentage = (100 * (inputFileSizeInBytes - outputFileSizeInBytes)) / inputFileSizeInBytes;
    logger("\n".concat(inputFile).concat(count ? ' with ' + count + ' features' : '', " minified successfully to ").concat(outputFile, ".\n"));
    if (keys) {
        logger('Key mapping:');
        logger(JSON.stringify(keys, null, 2) + '\n');
    }
    logger("Original size :\t".concat(inputFileSizeInBytes.toLocaleString('en-US', { minimumFractionDigits: 0 })));
    logger("Minified size :\t".concat(outputFileSizeInBytes.toLocaleString('en-US', { minimumFractionDigits: 0 })));
    logger("Reduction :   \t".concat(percentage.toLocaleString('en-US', { minimumFractionDigits: 2 }), "%"));
};
exports.reportLog = reportLog;
var createPropertyFilter = function (prop, op, val) {
    switch (op) {
        case '=':
            return function (props) { return props.hasOwnProperty(prop) && props[prop] == val; };
        case '<':
            return function (props) { return props.hasOwnProperty(prop) && props[prop] < val; };
        case '>':
            return function (props) { return props.hasOwnProperty(prop) && props[prop] > val; };
        case '<=':
            return function (props) { return props.hasOwnProperty(prop) && props[prop] <= val; };
        case '>=':
            return function (props) { return props.hasOwnProperty(prop) && props[prop] >= val; };
        case '!=':
            return function (props) { return props.hasOwnProperty(prop) && props[prop] != val; };
        default:
            throw new Error("Operator ".concat(op, " is not supported!"));
    }
};
exports.createPropertyFilter = createPropertyFilter;
var convertQueryToPropertyFilters = function (filterQuery) {
    var re = /^([a-zA-Z_\-0-9]*) *([!<>=]{1,2}) *([a-zA-Z_\-0-9]*)$/;
    var queries = filterQuery.split(',').map(function (q) { return q.trim(); });
    var filters = [];
    queries.forEach(function (q) {
        var m = re.exec(q);
        if (!m || m.length !== 4) {
            var errMsg = 'Filters should be in the form PROPERTY OPERATOR VALUE, where property is a string, OPERATOR is <, =, >, !=, <= or >=, and VALUE is a string or number.';
            console.error(errMsg);
            throw new Error(errMsg);
        }
        filters.push((0, exports.createPropertyFilter)(m[1].trim(), m[2].trim(), m[3].trim()));
    });
    return filters;
};
exports.convertQueryToPropertyFilters = convertQueryToPropertyFilters;
//# sourceMappingURL=utils.js.map